@@ -28,26 +28,26 @@ use Exporter;
 our @ISA = qw(Exporter);
 
 
-use constant VERSION => '6.1.24';
+use constant VERSION => '6.1.25';
 use constant USER    => 'sympa';
 use constant GROUP   => 'sympa';
 
-use constant CONFIG           => '/usr/local/sympa-stable/etc/sympa.conf';
-use constant WWSCONFIG        => '/usr/local/sympa-stable/etc/wwsympa.conf';
-use constant SENDMAIL_ALIASES => '/etc/mail/aliases-sympa-stable';
+use constant CONFIG           => '/usr/local/sympa-dv/etc/sympa.conf';
+use constant WWSCONFIG        => '/usr/local/sympa-dv/etc/wwsympa.conf';
+use constant SENDMAIL_ALIASES => '/etc/mail/aliases-sympa-dv';
 
-use constant PIDDIR     => '/usr/local/sympa-stable';
-use constant EXPLDIR    => '/usr/local/sympa-stable/list_data';
-use constant SPOOLDIR   => '/usr/local/sympa-stable/spool';
-use constant SYSCONFDIR => '/usr/local/sympa-stable/etc';
-use constant LOCALEDIR  => '/usr/local/sympa-stable/locale';
-use constant LIBEXECDIR => '/usr/local/sympa-stable/bin';
-use constant SBINDIR    => '/usr/local/sympa-stable/bin';
-use constant SCRIPTDIR  => '/usr/local/sympa-stable/bin';
-use constant MODULEDIR  => '/usr/local/sympa-stable/bin';
-use constant DEFAULTDIR => '/usr/local/sympa-stable/default';
-use constant STATICDIR  => '/usr/local/sympa-stable/static_content';
-use constant ARCDIR    => '/usr/local/sympa-stable/arc';
-use constant BOUNCEDIR  => '/usr/local/sympa-stable/bounce';
+use constant PIDDIR     => '/usr/local/sympa-dv';
+use constant EXPLDIR    => '/usr/local/sympa-dv/list_data';
+use constant SPOOLDIR   => '/usr/local/sympa-dv/spool';
+use constant SYSCONFDIR => '/usr/local/sympa-dv/etc';
+use constant LOCALEDIR  => '/usr/local/sympa-dv/locale';
+use constant LIBEXECDIR => '/usr/local/sympa-dv/bin';
+use constant SBINDIR    => '/usr/local/sympa-dv/bin';
+use constant SCRIPTDIR  => '/usr/local/sympa-dv/bin';
+use constant MODULEDIR  => '/usr/local/sympa-dv/bin';
+use constant DEFAULTDIR => '/usr/local/sympa-dv/default';
+use constant STATICDIR  => '/usr/local/sympa-dv/static_content';
+use constant ARCDIR    => '/usr/local/sympa-dv/arc';
+use constant BOUNCEDIR  => '/usr/local/sympa-dv/bounce';
 
 1;
